@@ -5,12 +5,22 @@ using namespace std;
 
 void showHelp()
 {
-    qDebug() << "SIMLock by Sierra Softworks\n";
-    qDebug() << "simlock [OPTIONS]\n";
-    qDebug() << "  -d      | Run in Daemon Mode\n";
-    qDebug() << "  --clear | Clear the valid SIM card database\n";
-    qDebug() << "  --help  | Show this help page\n";
-    qDebug() << "  --show  | Show a list of the valid SIM cards";
+    qDebug() << "SIMLock by Sierra Softworks";
+    qDebug() << "http://sierrasoftworks.com/simlock";
+    qDebug() << "";
+    qDebug() << "simlock [OPTIONS]";
+    qDebug() << "  --add -a	    [IMSI]";
+    qDebug() << "    Adds the specified IMSI to the database";
+    qDebug() << "  --remove -r	    [IMSI]";
+    qDebug() << "    Removes the specified IMSI from the database";
+    qDebug() << "  --show -s";
+    qDebug() << "    Show a list of the valid SIM cards";
+    qDebug() << "  --clear -c";
+    qDebug() << "    Clear the valid SIM card database";
+    qDebug() << "  -d";
+    qDebug() << "    Run in Daemon Mode";
+    qDebug() << "  --help -?";
+    qDebug() << "    Show this help page";
 }
 
 int main(int argc, char *argv[])
@@ -33,35 +43,32 @@ int main(int argc, char *argv[])
 	    qDebug() << "Starting SIMLockD";
 
 	    service.Run();
-
-	    qDebug() << "SIMLockD Exiting";
+	    qDebug() << "SIMLock Exiting";
+	    delete &service;
 	    return 0;
 	}
-	else if(arg == "--clear")
+	else if(arg == "--clear" || arg == "-c")
 	{
 	    //Clear the SIMLock database
 	    SIMLockService service;
 	    service.Initialize();
 	    service.ClearDatabase();
 	    service.Dispose();
+	    delete &service;
 	    return 0;
 	}
-	else if(arg == "--show")
+	else if(arg == "--show" || arg == "-s")
 	{
-	    qDebug() << "Creating Service Instace";
 	    SIMLockService service;
 	    service.Initialize();
 
-	    qDebug() << "Getting IMSI numbers";
 	    QList<QVariant> records = service.GetValidIMSIs();
 
 	    service.Dispose();
 
-	    qDebug() << "Printing IMSI numbers";
 
 	    if(records.length() > 0)
 	    {
-		qDebug() << "Valid IMSI Numbers:";
 		for(int i = 0; i < records.length();i++)
 		    qDebug() << "  " << records.at(i).toString();
 	    }
@@ -69,10 +76,11 @@ int main(int argc, char *argv[])
 	    {
 		qDebug() << "No Valid IMSI Numbers in Database";
 	    }
+	    delete &service;
 	    return 0;
 
 	}
-	else if(arg == "--add")
+	else if(arg == "--add" || arg == "-a")
 	{
 	    if(i == argc)
 	    {
@@ -86,9 +94,10 @@ int main(int argc, char *argv[])
 	    service.AddValidIMSI(QString(argv[i + 1]));
 	    service.Dispose();
 	    qDebug() << "IMSI Added";
+	    delete &service;
 	    return 0;
 	}
-	else if(arg == "--remove")
+	else if(arg == "--remove" || arg == "-r")
 	{
 	    if(i == argc)
 	    {
@@ -105,6 +114,7 @@ int main(int argc, char *argv[])
 	    if(!service.IsValidIMSI(imsi))
 	    {
 		qDebug() << "The provided IMSI is not in the database";
+		delete &service;
 		return 2;
 	    }
 
@@ -114,9 +124,10 @@ int main(int argc, char *argv[])
 
 	    service.Dispose();
 	    qDebug() << "IMSI Removed";
+	    delete &service;
 	    return 0;
 	}
-	else if(arg == "--help" || arg == "-?" || arg == "/?")
+	else if(arg == "--help" || arg == "-?")
 	{
 	    showHelp();
 	    return 0;
