@@ -8,7 +8,8 @@ SIMLock::SIMLock()
 
 SIMLock::~SIMLock()
 {
-
+    simlock.Dispose();
+    delete &simlock;
 }
 
 void SIMLock::Run()
@@ -25,6 +26,7 @@ void SIMLock::Run()
 	    simlock.AddValidIMSI(imsi);
 	    Notifications::ShowBanner("<b>SIMLock</b> has added this SIM card to the list of allowed SIMs");
 	}
+	delete &imsi;
     }
 
     if(!simlock.IsValidIMSI(imsi))
@@ -44,12 +46,11 @@ void SIMLock::Run()
 	    simlock.AddValidIMSI(imsi);
 	    Notifications::ShowBanner("<b>SIMLock</b> has added this SIM card to the list of allowed SIMs");
 	}
+	delete &imsi;
 	simlock.MakeOnline();
     }
     else
     {
 	qDebug() << "IMSI is Valid";
     }
-
-    simlock.Dispose();
 }
