@@ -7,7 +7,10 @@ SIMLockService::SIMLockService()
 
 SIMLockService::~SIMLockService()
 {
-    //Dispose();
+    Dispose();
+    delete dbInterface;
+    delete LockInterface;
+    delete SIMInterface;
 }
 
 void SIMLockService::Initialize()
@@ -26,7 +29,7 @@ void SIMLockService::Initialize()
     if(!SIMInterface->isValid())
 	qDebug() << "SIMInterface unavailable";
     if(!LockInterface->isValid())
-	qDebug() << "SIMInterface unavailable";
+	qDebug() << "LockInterface unavailable";
 }
 
 void SIMLockService::Dispose()
@@ -49,7 +52,10 @@ QString SIMLockService::GetIMSI()
 
     qDebug() << "Current IMSI:" << reply.value();
     emit IMSIRetrieved(reply.value());
-    return reply.value();
+
+    QString result = reply.value();
+    delete &reply;
+    return result;
 }
 
 void SIMLockService::LockPhone()
@@ -79,6 +85,8 @@ void SIMLockService::LockPhone()
 	else
 	    qDebug() << "Phone failed to lock";
 
+	delete &reply;
+
 }
 
 void SIMLockService::MakeOffline()
@@ -132,9 +140,13 @@ void SIMLockService::DeviceLockModeChanged(QString mode)
 bool SIMLockService::IsLocked()
 {
     QDBusReply<QString> reply = LockInterface->call("get_devicelock_mode");
-    if(!reply.isValid())
+    if(!reply.isValid() || reply.value() != "locked")
+    {
+	delete &reply;
 	return false;
-    return reply.value() == "locked";
+    }
+    delete &reply;
+    return true;
 }
 
 bool SIMLockService::ClearDatabase()
